// ----------------------------------------------------------------------------
//
// PneuSortMain.PAS                                      Ulrich Mller 26.12.99
//                                                       Procida 400NT  Delphi4
// Pneumatische Sortieranlage : Delphi4 Adaption
//                        des LLWin Programms PneuSort.MDL der Pneumatic Robots
//
// Der jeweilige Status wird auf der Form angezeigt (lblStatus)
//
// Nutzung umFish.DLL, ggf. PortNamen anpassen
//
// ----------------------------------------------------------------------------

unit PneuSortMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TfrmSortMain = class(TForm)
    cmdStart: TButton;
    cmdHalt: TButton;
    cmdEnde: TButton;
    lblTitel: TLabel;
    lblCopyright: TLabel;
    lblStatus: TLabel;
    procedure cmdEndeClick(Sender: TObject);
    procedure cmdHaltClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cmdStartClick(Sender: TObject);
  private
    procedure Init();
    procedure FachLinks();
    procedure FachRechts();
    procedure SortMain();
    procedure Schieber();
  public
    { Public-Deklarationen}
  end;

  var
     frmSortMain: TfrmSortMain;

implementation

{$R *.DFM}

uses umFish;

const
     cvMitte = 3; cvLinks = 2; cvRechts = 1;  // --- Magnetventile
     ctSchieber = 2;                          // --- Taster
     cmSchieber = 4;                          // --- Motor
     cpSensor = 1;                            // --- Fototransistor
var
  FishFace: TftiDCB; pFishFace: TpftiDCB;

procedure TfrmSortMain.cmdEndeClick(Sender: TObject);
begin
     close;
end;

procedure TfrmSortMain.cmdHaltClick(Sender: TObject);
// --- Setzen NotHalt, um Ende einzuleiten ----------
begin
     cmdStart.SetFocus;
     NotHalt := true;
end;

procedure TfrmSortMain.FormCreate(Sender: TObject);
begin
     pFishFace := @FishFace;
     NotHalt := true;
end;

procedure TfrmSortMain.cmdStartClick(Sender: TObject);
// --------- Starten der SortSteuerung ----------------
begin
     cmdHalt.SetFocus;
     if NotHalt then              // --- Ist beim Programmstart true
     begin
          NotHalt := false;
          if OpenInterface(pFishFace, 'COM1') = ftiFehler then
          begin
            MessageDlg('InterfaceProblem', mtInformation,[mbOK], 0);
            exit;
          end;                                    { ggf COMx anpassen }
          SortMain;               // --- TrSteuerung
          ClearMotors(pFishFace); // --- Ende
          cmdStart.SetFocus;
          lblStatus.Caption := 'START/ENDE';
          CloseInterface(pFishFace);
     end;
end;

procedure TfrmSortMain.Init;
// --- Initialisierung -----
begin
  lblStatus.Caption := 'Init luft';
  SetMotor(pFishFace, cvMitte, ftiEin);         // --- Auswerfer Mitte
  WaitForTime(pFishFace, 2000);
  SetMotor(pFishFace, cvMitte, ftiAus);
  SetMotor(pFishFace, cmSchieber, ftiRechts);   // --- Schieber zurck
  WaitForInput(pFishFace, ctSchieber);
  SetMotor(pFishFace, cmSchieber, ftiAus);
end;


procedure TfrmSortMain.FachLinks;
// --- Ablage in linken Kasten ---
begin
  lblStatus.Caption := 'in linkes Fach';
  SetMotor(pFishFace, cvLinks, ftiEin);       // --- Auswerfer nach links
  WaitForTime(pFishFace, 2000);
  SetMotor(pFishFace, cvLInks, ftiAus);
  WaitForTime(pFishFace, 1000);
  SetMotor(pFishFace, cvMitte, ftiEin);       // --- Auswerfer wieder Mitte
  WaitForTime(pFishFace, 2000);
  SetMotor(pFishFace, cvMitte, ftiAus);
end;

procedure TfrmSortMain.FachRechts;
// --- Ablage in rechtes Fach ----
begin
  lblStatus.Caption := 'in rechtes Fach';
  SetMotor(pFishFace, cvRechts, ftiEin);       // --- Auswerfer nach rechts
  WaitForTime(pFishFace, 2000);
  SetMotor(pFishFace, cvRechts, ftiAus);
  WaitForTime(pFishFace, 1000);
  SetMotor(pFishFace, cvMitte, ftiEin);        // --- Auswerfer wieder Mitte
  WaitForTime(pFishFace, 2000);
  SetMotor(pFishFace, cvMitte, ftiAus);
end;

procedure TfrmSortMain.Schieber;
// --- Ein Schieber Zyklus ---
begin
  lblStatus.Caption := 'Teil vorschieben';
  SetMotor(pFishFace, cmSchieber, ftiRechts);   // --- Schieber vor
  WaitForTime(pFishFace, 1500);                 //     kommt Taster frei
  WaitForInput(pFishFace, ctSchieber);          //     Schieber zurck
  SetMotor(pFishFace, cmSchieber, ftiAus);      //     am Taster
end;

procedure TfrmSortMain.SortMain;
// --- HauptProgramm, Schleife, die ber NotHalt beendet wird ---
begin
  Init;                             // --- auf Ausgangsstellung
  lblStatus.Caption := 'Anlage gestartet';
  Schieber;                         // --- erstes Teil schieben
  repeat
    if GetInput(pFishFace, cpSensor) then
      begin
      Schieber;                     // --- Teil unter Sensor : hell
      FachLinks;                    //     ins linke Fach
      end
    else
      begin
      Schieber;                     // --- Teil unter Sensor : dunkel
      FachRechts;                   //     ins rechte Fach
      end;
  until NotHalt;
end;

end.
